@@ -109,8 +109,8 @@ class RealtimeStorm(Storm):
             time_tropical = np.array(self.dict['time'])[idx]
             start_time = time_tropical[0].strftime("%H00 UTC %d %B %Y")
             end_time = time_tropical[-1].strftime("%H00 UTC %d %B %Y")
-            max_wind = 'N/A' if all_nan(np.array(self.dict['vmax'])[idx]) else np.nanmax(np.array(self.dict['vmax'])[idx])
-            min_mslp = 'N/A' if all_nan(np.array(self.dict['mslp'])[idx]) else np.nanmin(np.array(self.dict['mslp'])[idx])
+            max_wind = 'N/A' if all_nan(np.array(self.dict['vmax'])[idx]) else int(np.nanmax(np.array(self.dict['vmax'])[idx]))
+            min_mslp = 'N/A' if all_nan(np.array(self.dict['mslp'])[idx]) else int(np.nanmin(np.array(self.dict['mslp'])[idx]))
         summary_keys = {
             'Maximum Wind': f"{max_wind} knots",
             'Minimum Pressure': f"{min_mslp} hPa",
